From 9262b173014f9d1e811fe0b3be7b3810ed035b14 Mon Sep 17 00:00:00 2001
From: Calle Gunnarsson <calle.gunnarsson@gmail.com>
Date: Fri, 22 Aug 2014 12:06:24 +0200
Subject: [PATCH] Added support for parsing temperature in the dive header

Devices that only reports a single temperature in the header
will now be able to report it as well when they implement this.

Signed-off-by: Calle Gunnarsson <calle.gunnarsson@gmail.com>
---
 examples/universal.c             | 14 ++++++++++++++
 include/libdivecomputer/parser.h |  3 ++-
 2 files changed, 16 insertions(+), 1 deletion(-)

diff --git a/examples/universal.c b/examples/universal.c
index 1e0307b..89b053d 100644
--- a/examples/universal.c
+++ b/examples/universal.c
@@ -361,6 +361,20 @@ doparse (FILE *fp, dc_device_t *device, const unsigned char data[], unsigned int
 	fprintf (fp, "<divetime>%02u:%02u</divetime>\n",
 		divetime / 60, divetime % 60);
 
+	// Parse the mintemp.
+	message ("Parsing the temperature.\n");
+	double temperature = 0.0;
+	rc = dc_parser_get_field (parser, DC_FIELD_TEMPERATURE, 0, &temperature);
+	if (rc != DC_STATUS_SUCCESS && rc != DC_STATUS_UNSUPPORTED) {
+		WARNING ("Error parsing the temperature.");
+		dc_parser_destroy (parser);
+		return rc;
+	}
+
+	if (rc != DC_STATUS_UNSUPPORTED) {
+		fprintf (fp, "<temperature>%.1f</temperature>\n", temperature);
+	}
+
 	// Parse the maxdepth.
 	message ("Parsing the maxdepth.\n");
 	double maxdepth = 0.0;
diff --git a/include/libdivecomputer/parser.h b/include/libdivecomputer/parser.h
index 65b18c9..a1919a9 100644
--- a/include/libdivecomputer/parser.h
+++ b/include/libdivecomputer/parser.h
@@ -53,7 +53,8 @@ typedef enum dc_field_type_t {
 	DC_FIELD_GASMIX_COUNT,
 	DC_FIELD_GASMIX,
 	DC_FIELD_SALINITY,
-	DC_FIELD_ATMOSPHERIC
+	DC_FIELD_ATMOSPHERIC,
+	DC_FIELD_TEMPERATURE
 } dc_field_type_t;
 
 typedef enum parser_sample_event_t {
-- 
2.1.0

